@@ -52,6 +52,9 @@ void nimArr_rmnorm_chol(NimArr<1, double> &ans, NimArr<1, double> &mean, NimArr<
 double nimArr_dmvt_chol(NimArr<1, double> &x, NimArr<1, double> &mean, NimArr<2, double> &chol, double df, double prec_param, int give_log, int overwrite_inputs);
 void nimArr_rmvt_chol(NimArr<1, double> &ans, NimArr<1, double> &mean, NimArr<2, double> &chol, double df, double prec_param);
 
+double nimArr_dlkj_corr_cholesky(NimArr<2, double> &x, double eta, int p, int give_log);
+void nimArr_rlkj_corr_cholesky(NimArr<2, double> &ans, double eta, int p);
+
 double nimArr_dinterval(double x, double t, NimArr<1, double> &c, int give_log);
 int nimArr_rinterval(double t, NimArr<1, double> &c);
 
